@@ -6,6 +6,7 @@ from .pytest_mock_fixtures import (
     lambda_context_mock,
     get_sns_lambda_event_mock,
 )
+from .utils import call_handler, notify_handler
 
 __all__ = [
     "middleware_mock",
@@ -14,4 +15,6 @@ __all__ = [
     "NotificationManagerMock",
     "lambda_context_mock",
     "get_sns_lambda_event_mock",
+    "call_handler",
+    "notify_handler",
 ]
