@@ -44,38 +44,42 @@ def NotificationManagerMock(monkeypatch):
     return thlink_backend_notification_lib.NotificationManagerMock
 
 
+@dataclass
+class _LambdaContextMock:
+    function_name: str = "test"
+    memory_limit_in_mb: int = 128
+    invoked_function_arn: str = "arn:aws:lambda:eu-west-1:809313241:function:test"
+    aws_request_id: str = "52fdfc07-2182-154f-163f-5f0f9a621d72"
+
+
 @pytest.fixture
 def lambda_context_mock():
-    @dataclass
-    class LambdaContext:
-        function_name: str = "test"
-        memory_limit_in_mb: int = 128
-        invoked_function_arn: str = "arn:aws:lambda:eu-west-1:809313241:function:test"
-        aws_request_id: str = "52fdfc07-2182-154f-163f-5f0f9a621d72"
-    return LambdaContext()
+    return _LambdaContextMock()
+
+
+def _get_sns_lambda_event_mock(message):
+    # model
+    return SnsModel(Records=[SnsRecordModel(
+        EventSource="aws:sns",
+        EventVersion="",
+        EventSubscriptionArn="",
+        Sns=SnsNotificationModel(
+            Subject="",
+            TopicArn="",
+            UnsubscribeUrl="http://google.com",
+            Type="Notification",
+            MessageAttributes={},
+            Message=message,
+            MessageId="",
+            SigningCertUrl="http://google.com",
+            Signature="",
+            Timestamp="2021-06-03 00:00:00",
+            SignatureVersion="",
+        ),
+    )])
 
 
 @pytest.fixture
 def get_sns_lambda_event_mock():
     # model
-    # TODO
-    def get(message: str):
-        return SnsModel(Records=[SnsRecordModel(
-            EventSource="aws:sns",
-            EventVersion="",
-            EventSubscriptionArn="",
-            Sns=SnsNotificationModel(
-                Subject="",
-                TopicArn="",
-                UnsubscribeUrl="http://google.com",
-                Type="Notification",
-                MessageAttributes={},
-                Message=message,
-                MessageId="",
-                SigningCertUrl="http://google.com",
-                Signature="",
-                Timestamp="2021-06-03 00:00:00",
-                SignatureVersion="",
-            ),
-        )])
-    return get
+    return _get_sns_lambda_event_mock
